package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.common.security.utils.SecurityUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsBaseLubeStationMapper;
import com.hw.dms.domain.DmsBaseLubeStation;
import com.hw.dms.service.IDmsBaseLubeStationService;

/**
 * 润滑部位信息Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@Service
public class DmsBaseLubeStationServiceImpl implements IDmsBaseLubeStationService
{
    @Autowired
    private DmsBaseLubeStationMapper dmsBaseLubeStationMapper;

    /**
     * 查询润滑部位信息
     *
     * @param lubeStationId 润滑部位信息主键
     * @return 润滑部位信息
     */
    @Override
    public DmsBaseLubeStation selectDmsBaseLubeStationByLubeStationId(Long lubeStationId)
    {
        return dmsBaseLubeStationMapper.selectDmsBaseLubeStationByLubeStationId(lubeStationId);
    }

    /**
     * 查询润滑部位信息列表
     *
     * @param dmsBaseLubeStation 润滑部位信息
     * @return 润滑部位信息
     */
    @Override
    public List<DmsBaseLubeStation> selectDmsBaseLubeStationList(DmsBaseLubeStation dmsBaseLubeStation)
    {
        return dmsBaseLubeStationMapper.selectDmsBaseLubeStationList(dmsBaseLubeStation);
    }

    /**
     * 新增润滑部位信息
     *
     * @param dmsBaseLubeStation 润滑部位信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseLubeStation(DmsBaseLubeStation dmsBaseLubeStation)
    {
        LoginUser  user = new LoginUser();
        dmsBaseLubeStation.setIsFlag("1");
        dmsBaseLubeStation.setCreateBy(user.getUsername());
        dmsBaseLubeStation.setCreateTime(DateUtils.getNowDate());
        return dmsBaseLubeStationMapper.insertDmsBaseLubeStation(dmsBaseLubeStation);
    }

    /**
     * 修改润滑部位信息
     *
     * @param dmsBaseLubeStation 润滑部位信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseLubeStation(DmsBaseLubeStation dmsBaseLubeStation)
    {
        LoginUser user = SecurityUtils.getLoginUser();
        dmsBaseLubeStation.setUpdateBy(user.getUsername());
        dmsBaseLubeStation.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseLubeStationMapper.updateDmsBaseLubeStation(dmsBaseLubeStation);
    }

    /**
     * 批量删除润滑部位信息
     *
     * @param lubeStationIds 需要删除的润滑部位信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseLubeStationByLubeStationIds(Long[] lubeStationIds)
    {
        return dmsBaseLubeStationMapper.deleteDmsBaseLubeStationByLubeStationIds(lubeStationIds);
    }

    /**
     * 删除润滑部位信息信息
     *
     * @param lubeStationId 润滑部位信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseLubeStationByLubeStationId(Long lubeStationId)
    {
        return dmsBaseLubeStationMapper.deleteDmsBaseLubeStationByLubeStationId(lubeStationId);
    }
}
