package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseLubeStation;
import com.hw.dms.service.IDmsBaseLubeStationService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 润滑部位信息Controller
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/lubeStation")
public class DmsBaseLubeStationController extends BaseController
{
    @Autowired
    private IDmsBaseLubeStationService dmsBaseLubeStationService;

    /**
     * 查询润滑部位信息列表
     */
    @RequiresPermissions("dms:lubeStation:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseLubeStation dmsBaseLubeStation)
    {
        startPage();
        List<DmsBaseLubeStation> list = dmsBaseLubeStationService.selectDmsBaseLubeStationList(dmsBaseLubeStation);
        return getDataTable(list);
    }

    /**
     * 导出润滑部位信息列表
     */
    @RequiresPermissions("dms:lubeStation:export")
    @Log(title = "润滑部位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseLubeStation dmsBaseLubeStation)
    {
        List<DmsBaseLubeStation> list = dmsBaseLubeStationService.selectDmsBaseLubeStationList(dmsBaseLubeStation);
        ExcelUtil<DmsBaseLubeStation> util = new ExcelUtil<DmsBaseLubeStation>(DmsBaseLubeStation.class);
        util.exportExcel(response, list, "润滑部位信息数据");
    }

    /**
     * 获取润滑部位信息详细信息
     */
    @RequiresPermissions("dms:lubeStation:query")
    @GetMapping(value = "/{lubeStationId}")
    public AjaxResult getInfo(@PathVariable("lubeStationId") Long lubeStationId)
    {
        return success(dmsBaseLubeStationService.selectDmsBaseLubeStationByLubeStationId(lubeStationId));
    }

    /**
     * 新增润滑部位信息
     */
    @RequiresPermissions("dms:lubeStation:add")
    @Log(title = "润滑部位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseLubeStation dmsBaseLubeStation)
    {
        return toAjax(dmsBaseLubeStationService.insertDmsBaseLubeStation(dmsBaseLubeStation));
    }

    /**
     * 修改润滑部位信息
     */
    @RequiresPermissions("dms:lubeStation:edit")
    @Log(title = "润滑部位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseLubeStation dmsBaseLubeStation)
    {
        return toAjax(dmsBaseLubeStationService.updateDmsBaseLubeStation(dmsBaseLubeStation));
    }

    /**
     * 删除润滑部位信息
     */
    @RequiresPermissions("dms:lubeStation:remove")
    @Log(title = "润滑部位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{lubeStationIds}")
    public AjaxResult remove(@PathVariable Long[] lubeStationIds)
    {
        return toAjax(dmsBaseLubeStationService.deleteDmsBaseLubeStationByLubeStationIds(lubeStationIds));
    }
}
